@@ -67,7 +67,9 @@ class Downloader(object):
         """
         videos = []
         for vid in self._extract_content_ids(self._fetch_html(show)):
-            videos.append(self.fetch_config(show, vid))
+            vod = self.fetch_config(show, vid)
+            if vod:
+                videos.append(vod)
         return videos
 
     def get_cached_configs(self):
@@ -82,8 +84,9 @@ class Downloader(object):
 
             full_name = os.path.join(md_dir, filename)
             vod = self._video_url(open(full_name).read(), show, vid)
-            vod.metadata = full_name
-            videos.setdefault(show, set()).add(vod)
+            if vod:
+                vod.metadata = full_name
+                videos.setdefault(show, set()).add(vod)
         return videos
 
     def _fetch_html(self, show):
@@ -129,13 +132,21 @@ class Downloader(object):
             open(target, 'w').write(data)
 
         vod = self._video_url(data, show, vid)
-        vod.metadata = target
+        if vod:
+            vod.metadata = target
         return vod
 
     def _video_url(self, data, show, vid):
-        """Parse the XML metadata and extract the video strsm URL."""
+        """Parse the XML metadata and extract the video stream URL."""
         tree = ElementTree.ElementTree(ElementTree.XML(data))
-        url = tree.find('//video/hi').text
+        url = None
+        for node in (tree.find('//video/hi'),
+                     tree.find('//video/low')):
+            if node is not None and node.text:
+                url = node.text
+                break
+        else:
+            return None
         # heuristic to get date from filename...
         match = re.search(r'_(\d{6})_', url.split('/')[-1])
         if match:
